<?php

declare(strict_types=1);

namespace Dedi\SyliusMailAdminPlugin\EventListener\Mail;

use Dedi\SyliusMailAdminPlugin\Repository\MailRepositoryInterface;
use Sylius\Bundle\AdminBundle\EmailManager\ShipmentEmailManagerInterface;
use Sylius\Bundle\CoreBundle\Mailer\Emails;
use Sylius\Component\Core\Model\OrderInterface;
use Sylius\Component\Core\Model\ShipmentInterface;
use Sylius\Component\Mailer\Sender\SenderInterface;
use Webmozart\Assert\Assert;

class ShipmentEmailManager implements ShipmentEmailManagerInterface
{
    public function __construct(
        private SenderInterface $emailSender,
        private MailRepositoryInterface $mailRepository,
    ) {
    }

    public function sendConfirmationEmail(ShipmentInterface $shipment): void
    {
        /** @var OrderInterface $order */
        $order = $shipment->getOrder();
        $email = $order->getCustomer()->getEmail();
        Assert::notNull($email);

        $mails = $this->mailRepository->findByCode(Emails::SHIPMENT_CONFIRMATION);

        foreach ($mails as $mail) {
            if ($mail->isEnabled()) {
                $this->emailSender->send(
                    Emails::SHIPMENT_CONFIRMATION,
                    [$email],
                    [
                        'shipment' => $shipment,
                        'order' => $order,
                        'channel' => $order->getChannel(),
                        'localeCode' => $order->getLocaleCode(),
                    ],
                );
            }
        }
    }
}
